Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ErrSnapAlreadyExists ¶
type ErrSnapAlreadyExists struct {
// contains filtered or unexported fields
}
ErrSnapAlreadyExists is used to indicate when a snapshot is thought to be knew, but in fact is already present
func SnapAlreadyExists ¶
func SnapAlreadyExists(err error) ErrSnapAlreadyExists
SnapAlreadyExists wraps error
type ErrSnapNotFound ¶
type ErrSnapNotFound struct {
// contains filtered or unexported fields
}
ErrSnapNotFound indicates that a snapshot cannot be located
type ErrSnapsEmpty ¶
type ErrSnapsEmpty struct {
// contains filtered or unexported fields
}
ErrSnapsEmpty indicates that no snaps were loaded when it was expected that they would be
type ErrSnapshotMismatch ¶
type ErrSnapshotMismatch struct {
// contains filtered or unexported fields
}
ErrSnapshotMismatch is returned when the snapshot generated doesn't match that on file
func SnapshotMismatch ¶
func SnapshotMismatch(err error) ErrSnapshotMismatch
SnapshotMismatch wraps error
Click to show internal directories.
Click to hide internal directories.